@@ -25,6 +25,12 @@ if($FoundErr!=true){$password=md5($password);
 		$ErrMsg=$ErrMsg."<br><li>The name or password error</li>";
 	}
 	else{
+		$query=$db->query("SELECT session_time from system ");
+		$rs=$db->fetch_array($query);
+		$session_time=$rs[0]*60;
+
+		//if($session_time<300) $session_time=300; 
+		setcookie(session_name(), session_id(), time() + $session_time, "/");
                 $_SESSION['goip_username'] = $username;
                 $_SESSION['goip_userid'] = $adminId;
                 $_SESSION['goip_permissions'] = $rs['permissions'];
