@@ -332,5 +332,10 @@
 	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `bal_delay` int(11) NOT NULL default '0'");
 	@$db->updatequery("ALTER TABLE  `system` ADD `session_time` int(11) NOT NULL default '24'");
 	
+
+/*1.20.1*/
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_enable` tinyint(1) NOT NULL");
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_cmd` varchar(64) NOT NULL");
+	@$db->updatequery("ALTER TABLE `auto_ussd` ADD `re_step2_ok_r` varchar(64) character set utf8 NOT NULL");
 	echo "update done! <a href=''  target=_top>Return</a>";
 ?>
